# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ImportDeclaration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        '_as': 'Identifier',
        'path': 'StringLiteral'
    }

    attribute_map = {
        'type': 'type',
        '_as': 'as',
        'path': 'path'
    }

    def __init__(self, type=None, _as=None, path=None):  # noqa: E501
        """ImportDeclaration - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self.__as = None
        self._path = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if _as is not None:
            self._as = _as
        if path is not None:
            self.path = path

    @property
    def type(self):
        """Gets the type of this ImportDeclaration.  # noqa: E501

        type of AST node  # noqa: E501

        :return: The type of this ImportDeclaration.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ImportDeclaration.

        type of AST node  # noqa: E501

        :param type: The type of this ImportDeclaration.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def _as(self):
        """Gets the _as of this ImportDeclaration.  # noqa: E501


        :return: The _as of this ImportDeclaration.  # noqa: E501
        :rtype: Identifier
        """
        return self.__as

    @_as.setter
    def _as(self, _as):
        """Sets the _as of this ImportDeclaration.


        :param _as: The _as of this ImportDeclaration.  # noqa: E501
        :type: Identifier
        """

        self.__as = _as

    @property
    def path(self):
        """Gets the path of this ImportDeclaration.  # noqa: E501


        :return: The path of this ImportDeclaration.  # noqa: E501
        :rtype: StringLiteral
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ImportDeclaration.


        :param path: The path of this ImportDeclaration.  # noqa: E501
        :type: StringLiteral
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportDeclaration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class SMTPNotificationRuleBase(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'subject_template': 'str',
        'body_template': 'str',
        'to': 'str'
    }

    attribute_map = {
        'type': 'type',
        'subject_template': 'subjectTemplate',
        'body_template': 'bodyTemplate',
        'to': 'to'
    }

    def __init__(self, type=None, subject_template=None, body_template=None, to=None):  # noqa: E501
        """SMTPNotificationRuleBase - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._subject_template = None
        self._body_template = None
        self._to = None
        self.discriminator = None

        self.type = type
        self.subject_template = subject_template
        if body_template is not None:
            self.body_template = body_template
        self.to = to

    @property
    def type(self):
        """Gets the type of this SMTPNotificationRuleBase.  # noqa: E501


        :return: The type of this SMTPNotificationRuleBase.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SMTPNotificationRuleBase.


        :param type: The type of this SMTPNotificationRuleBase.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["smtp"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def subject_template(self):
        """Gets the subject_template of this SMTPNotificationRuleBase.  # noqa: E501


        :return: The subject_template of this SMTPNotificationRuleBase.  # noqa: E501
        :rtype: str
        """
        return self._subject_template

    @subject_template.setter
    def subject_template(self, subject_template):
        """Sets the subject_template of this SMTPNotificationRuleBase.


        :param subject_template: The subject_template of this SMTPNotificationRuleBase.  # noqa: E501
        :type: str
        """
        if subject_template is None:
            raise ValueError("Invalid value for `subject_template`, must not be `None`")  # noqa: E501

        self._subject_template = subject_template

    @property
    def body_template(self):
        """Gets the body_template of this SMTPNotificationRuleBase.  # noqa: E501


        :return: The body_template of this SMTPNotificationRuleBase.  # noqa: E501
        :rtype: str
        """
        return self._body_template

    @body_template.setter
    def body_template(self, body_template):
        """Sets the body_template of this SMTPNotificationRuleBase.


        :param body_template: The body_template of this SMTPNotificationRuleBase.  # noqa: E501
        :type: str
        """

        self._body_template = body_template

    @property
    def to(self):
        """Gets the to of this SMTPNotificationRuleBase.  # noqa: E501


        :return: The to of this SMTPNotificationRuleBase.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this SMTPNotificationRuleBase.


        :param to: The to of this SMTPNotificationRuleBase.  # noqa: E501
        :type: str
        """
        if to is None:
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SMTPNotificationRuleBase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class TagRule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'value': 'str',
        'operator': 'str'
    }

    attribute_map = {
        'key': 'key',
        'value': 'value',
        'operator': 'operator'
    }

    def __init__(self, key=None, value=None, operator=None):  # noqa: E501
        """TagRule - a model defined in OpenAPI"""  # noqa: E501

        self._key = None
        self._value = None
        self._operator = None
        self.discriminator = None

        if key is not None:
            self.key = key
        if value is not None:
            self.value = value
        if operator is not None:
            self.operator = operator

    @property
    def key(self):
        """Gets the key of this TagRule.  # noqa: E501


        :return: The key of this TagRule.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this TagRule.


        :param key: The key of this TagRule.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def value(self):
        """Gets the value of this TagRule.  # noqa: E501


        :return: The value of this TagRule.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this TagRule.


        :param value: The value of this TagRule.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def operator(self):
        """Gets the operator of this TagRule.  # noqa: E501


        :return: The operator of this TagRule.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this TagRule.


        :param operator: The operator of this TagRule.  # noqa: E501
        :type: str
        """
        allowed_values = ["equal", "notequal", "equalregex", "notequalregex"]  # noqa: E501
        if operator not in allowed_values:
            raise ValueError(
                "Invalid value for `operator` ({0}), must be one of {1}"  # noqa: E501
                .format(operator, allowed_values)
            )

        self._operator = operator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagRule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six
from influxdb_client.domain.check_base import CheckBase


class ThresholdCheck(CheckBase):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'thresholds': 'list[Threshold]',
        'id': 'str',
        'name': 'str',
        'org_id': 'str',
        'owner_id': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'query': 'DashboardQuery',
        'status': 'TaskStatusType',
        'every': 'str',
        'offset': 'str',
        'cron': 'str',
        'tags': 'list[CheckBaseTags]',
        'description': 'str',
        'status_message_template': 'str',
        'labels': 'list[Label]'
    }

    attribute_map = {
        'type': 'type',
        'thresholds': 'thresholds',
        'id': 'id',
        'name': 'name',
        'org_id': 'orgID',
        'owner_id': 'ownerID',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'query': 'query',
        'status': 'status',
        'every': 'every',
        'offset': 'offset',
        'cron': 'cron',
        'tags': 'tags',
        'description': 'description',
        'status_message_template': 'statusMessageTemplate',
        'labels': 'labels'
    }

    def __init__(self, type=None, thresholds=None, id=None, name=None, org_id=None, owner_id=None, created_at=None, updated_at=None, query=None, status=None, every=None, offset=None, cron=None, tags=None, description=None, status_message_template=None, labels=None):  # noqa: E501
        """ThresholdCheck - a model defined in OpenAPI"""  # noqa: E501
        CheckBase.__init__(self, id=id, name=name, org_id=org_id, owner_id=owner_id, created_at=created_at, updated_at=updated_at, query=query, status=status, every=every, offset=offset, cron=cron, tags=tags, description=description, status_message_template=status_message_template, labels=labels)

        self._type = None
        self._thresholds = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if thresholds is not None:
            self.thresholds = thresholds

    @property
    def type(self):
        """Gets the type of this ThresholdCheck.  # noqa: E501


        :return: The type of this ThresholdCheck.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ThresholdCheck.


        :param type: The type of this ThresholdCheck.  # noqa: E501
        :type: str
        """
        allowed_values = ["threshold"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def thresholds(self):
        """Gets the thresholds of this ThresholdCheck.  # noqa: E501


        :return: The thresholds of this ThresholdCheck.  # noqa: E501
        :rtype: list[Threshold]
        """
        return self._thresholds

    @thresholds.setter
    def thresholds(self, thresholds):
        """Sets the thresholds of this ThresholdCheck.


        :param thresholds: The thresholds of this ThresholdCheck.  # noqa: E501
        :type: list[Threshold]
        """

        self._thresholds = thresholds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThresholdCheck):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from influxdb_client.api_client import ApiClient


class VariablesService(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_variables_id(self, variable_id, **kwargs):  # noqa: E501
        """delete a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
            return data

    def delete_variables_id_with_http_info(self, variable_id, **kwargs):  # noqa: E501
        """delete a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id_with_http_info(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `delete_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_variables_id_labels_id(self, variable_id, label_id, **kwargs):  # noqa: E501
        """delete a label from a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id_labels_id(variable_id, label_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str label_id: the label id to delete (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_variables_id_labels_id_with_http_info(variable_id, label_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_variables_id_labels_id_with_http_info(variable_id, label_id, **kwargs)  # noqa: E501
            return data

    def delete_variables_id_labels_id_with_http_info(self, variable_id, label_id, **kwargs):  # noqa: E501
        """delete a label from a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_variables_id_labels_id_with_http_info(variable_id, label_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str label_id: the label id to delete (required)
        :param str zap_trace_span: OpenTracing span context
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'label_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_variables_id_labels_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `delete_variables_id_labels_id`")  # noqa: E501
        # verify the required parameter 'label_id' is set
        if ('label_id' not in local_var_params or
                local_var_params['label_id'] is None):
            raise ValueError("Missing the required parameter `label_id` when calling `delete_variables_id_labels_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501
        if 'label_id' in local_var_params:
            path_params['labelID'] = local_var_params['label_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}/labels/{labelID}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variables(self, **kwargs):  # noqa: E501
        """get all variables  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str org: specifies the organization name of the resource
        :param str org_id: specifies the organization id of the resource
        :return: Variables
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_variables_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_variables_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_variables_with_http_info(self, **kwargs):  # noqa: E501
        """get all variables  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str zap_trace_span: OpenTracing span context
        :param str org: specifies the organization name of the resource
        :param str org_id: specifies the organization id of the resource
        :return: Variables
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['zap_trace_span', 'org', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variables" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variables',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variables_id(self, variable_id, **kwargs):  # noqa: E501
        """get a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_variables_id_with_http_info(variable_id, **kwargs)  # noqa: E501
            return data

    def get_variables_id_with_http_info(self, variable_id, **kwargs):  # noqa: E501
        """get a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id_with_http_info(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `get_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_variables_id_labels(self, variable_id, **kwargs):  # noqa: E501
        """list all labels for a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id_labels(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_variables_id_labels_with_http_info(variable_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_variables_id_labels_with_http_info(variable_id, **kwargs)  # noqa: E501
            return data

    def get_variables_id_labels_with_http_info(self, variable_id, **kwargs):  # noqa: E501
        """list all labels for a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_variables_id_labels_with_http_info(variable_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_variables_id_labels" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `get_variables_id_labels`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}/labels', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LabelsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def patch_variables_id(self, variable_id, variable, **kwargs):  # noqa: E501
        """update a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_variables_id(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable update to apply (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.patch_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
        else:
            (data) = self.patch_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
            return data

    def patch_variables_id_with_http_info(self, variable_id, variable, **kwargs):  # noqa: E501
        """update a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.patch_variables_id_with_http_info(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable update to apply (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'variable', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `patch_variables_id`")  # noqa: E501
        # verify the required parameter 'variable' is set
        if ('variable' not in local_var_params or
                local_var_params['variable'] is None):
            raise ValueError("Missing the required parameter `variable` when calling `patch_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variable' in local_var_params:
            body_params = local_var_params['variable']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_variables(self, variable, **kwargs):  # noqa: E501
        """create a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables(variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Variable variable: variable to create (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_variables_with_http_info(variable, **kwargs)  # noqa: E501
        else:
            (data) = self.post_variables_with_http_info(variable, **kwargs)  # noqa: E501
            return data

    def post_variables_with_http_info(self, variable, **kwargs):  # noqa: E501
        """create a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables_with_http_info(variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Variable variable: variable to create (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_variables" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable' is set
        if ('variable' not in local_var_params or
                local_var_params['variable'] is None):
            raise ValueError("Missing the required parameter `variable` when calling `post_variables`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variable' in local_var_params:
            body_params = local_var_params['variable']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_variables_id_labels(self, variable_id, label_mapping, **kwargs):  # noqa: E501
        """add a label to a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables_id_labels(variable_id, label_mapping, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param LabelMapping label_mapping: label to add (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_variables_id_labels_with_http_info(variable_id, label_mapping, **kwargs)  # noqa: E501
        else:
            (data) = self.post_variables_id_labels_with_http_info(variable_id, label_mapping, **kwargs)  # noqa: E501
            return data

    def post_variables_id_labels_with_http_info(self, variable_id, label_mapping, **kwargs):  # noqa: E501
        """add a label to a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_variables_id_labels_with_http_info(variable_id, label_mapping, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: ID of the variable (required)
        :param LabelMapping label_mapping: label to add (required)
        :param str zap_trace_span: OpenTracing span context
        :return: LabelResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'label_mapping', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_variables_id_labels" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `post_variables_id_labels`")  # noqa: E501
        # verify the required parameter 'label_mapping' is set
        if ('label_mapping' not in local_var_params or
                local_var_params['label_mapping'] is None):
            raise ValueError("Missing the required parameter `label_mapping` when calling `post_variables_id_labels`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'label_mapping' in local_var_params:
            body_params = local_var_params['label_mapping']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}/labels', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LabelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_variables_id(self, variable_id, variable, **kwargs):  # noqa: E501
        """replace a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_variables_id(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable to replace (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
        else:
            (data) = self.put_variables_id_with_http_info(variable_id, variable, **kwargs)  # noqa: E501
            return data

    def put_variables_id_with_http_info(self, variable_id, variable, **kwargs):  # noqa: E501
        """replace a variable  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_variables_id_with_http_info(variable_id, variable, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str variable_id: id of the variable (required)
        :param Variable variable: variable to replace (required)
        :param str zap_trace_span: OpenTracing span context
        :return: Variable
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['variable_id', 'variable', 'zap_trace_span']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_variables_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'variable_id' is set
        if ('variable_id' not in local_var_params or
                local_var_params['variable_id'] is None):
            raise ValueError("Missing the required parameter `variable_id` when calling `put_variables_id`")  # noqa: E501
        # verify the required parameter 'variable' is set
        if ('variable' not in local_var_params or
                local_var_params['variable'] is None):
            raise ValueError("Missing the required parameter `variable` when calling `put_variables_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'variable_id' in local_var_params:
            path_params['variableID'] = local_var_params['variable_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'variable' in local_var_params:
            body_params = local_var_params['variable']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/variables/{variableID}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Variable',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class DocumentCreate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'meta': 'DocumentMeta',
        'content': 'object',
        'org': 'str',
        'org_id': 'str',
        'labels': 'list[str]'
    }

    attribute_map = {
        'meta': 'meta',
        'content': 'content',
        'org': 'org',
        'org_id': 'orgID',
        'labels': 'labels'
    }

    def __init__(self, meta=None, content=None, org=None, org_id=None, labels=None):  # noqa: E501
        """DocumentCreate - a model defined in OpenAPI"""  # noqa: E501

        self._meta = None
        self._content = None
        self._org = None
        self._org_id = None
        self._labels = None
        self.discriminator = None

        self.meta = meta
        self.content = content
        if org is not None:
            self.org = org
        if org_id is not None:
            self.org_id = org_id
        if labels is not None:
            self.labels = labels

    @property
    def meta(self):
        """Gets the meta of this DocumentCreate.  # noqa: E501


        :return: The meta of this DocumentCreate.  # noqa: E501
        :rtype: DocumentMeta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this DocumentCreate.


        :param meta: The meta of this DocumentCreate.  # noqa: E501
        :type: DocumentMeta
        """
        if meta is None:
            raise ValueError("Invalid value for `meta`, must not be `None`")  # noqa: E501

        self._meta = meta

    @property
    def content(self):
        """Gets the content of this DocumentCreate.  # noqa: E501


        :return: The content of this DocumentCreate.  # noqa: E501
        :rtype: object
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this DocumentCreate.


        :param content: The content of this DocumentCreate.  # noqa: E501
        :type: object
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def org(self):
        """Gets the org of this DocumentCreate.  # noqa: E501

        must specify one of orgID and org  # noqa: E501

        :return: The org of this DocumentCreate.  # noqa: E501
        :rtype: str
        """
        return self._org

    @org.setter
    def org(self, org):
        """Sets the org of this DocumentCreate.

        must specify one of orgID and org  # noqa: E501

        :param org: The org of this DocumentCreate.  # noqa: E501
        :type: str
        """

        self._org = org

    @property
    def org_id(self):
        """Gets the org_id of this DocumentCreate.  # noqa: E501

        must specify one of orgID and org  # noqa: E501

        :return: The org_id of this DocumentCreate.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this DocumentCreate.

        must specify one of orgID and org  # noqa: E501

        :param org_id: The org_id of this DocumentCreate.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def labels(self):
        """Gets the labels of this DocumentCreate.  # noqa: E501

        this is an array of label IDs that will be added as labels to the document  # noqa: E501

        :return: The labels of this DocumentCreate.  # noqa: E501
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this DocumentCreate.

        this is an array of label IDs that will be added as labels to the document  # noqa: E501

        :param labels: The labels of this DocumentCreate.  # noqa: E501
        :type: list[str]
        """

        self._labels = labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from influxdb_client.api_client import ApiClient


class WriteService(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def post_write(self, org, bucket, body, **kwargs):  # noqa: E501
        """write time-series data into influxdb  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_write(org, bucket, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org: specifies the destination organization for writes; take either the ID or Name interchangeably; if both orgID and org are specified, org takes precedence. (required)
        :param str bucket: specifies the destination bucket for writes (required)
        :param str body: line protocol body (required)
        :param str zap_trace_span: OpenTracing span context
        :param str content_encoding: when present, its value indicates to the database that compression is applied to the line-protocol body.
        :param str content_type: Content-Type is used to indicate the format of the data sent to the server.
        :param int content_length: Content-Length is an entity header is indicating the size of the entity-body, in bytes, sent to the database. If the length is greater than the database max body configuration option, a 413 response is sent.
        :param str accept: specifies the return content format.
        :param str org_id: specifies the ID of the destination organization for writes; if both orgID and org are specified, org takes precedence.
        :param WritePrecision precision: specifies the precision for the unix timestamps within the body line-protocol
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_write_with_http_info(org, bucket, body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_write_with_http_info(org, bucket, body, **kwargs)  # noqa: E501
            return data

    def post_write_with_http_info(self, org, bucket, body, **kwargs):  # noqa: E501
        """write time-series data into influxdb  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_write_with_http_info(org, bucket, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org: specifies the destination organization for writes; take either the ID or Name interchangeably; if both orgID and org are specified, org takes precedence. (required)
        :param str bucket: specifies the destination bucket for writes (required)
        :param str body: line protocol body (required)
        :param str zap_trace_span: OpenTracing span context
        :param str content_encoding: when present, its value indicates to the database that compression is applied to the line-protocol body.
        :param str content_type: Content-Type is used to indicate the format of the data sent to the server.
        :param int content_length: Content-Length is an entity header is indicating the size of the entity-body, in bytes, sent to the database. If the length is greater than the database max body configuration option, a 413 response is sent.
        :param str accept: specifies the return content format.
        :param str org_id: specifies the ID of the destination organization for writes; if both orgID and org are specified, org takes precedence.
        :param WritePrecision precision: specifies the precision for the unix timestamps within the body line-protocol
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['org', 'bucket', 'body', 'zap_trace_span', 'content_encoding', 'content_type', 'content_length', 'accept', 'org_id', 'precision']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_write" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'org' is set
        if ('org' not in local_var_params or
                local_var_params['org'] is None):
            raise ValueError("Missing the required parameter `org` when calling `post_write`")  # noqa: E501
        # verify the required parameter 'bucket' is set
        if ('bucket' not in local_var_params or
                local_var_params['bucket'] is None):
            raise ValueError("Missing the required parameter `bucket` when calling `post_write`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in local_var_params or
                local_var_params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_write`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'org' in local_var_params:
            query_params.append(('org', local_var_params['org']))  # noqa: E501
        if 'org_id' in local_var_params:
            query_params.append(('orgID', local_var_params['org_id']))  # noqa: E501
        if 'bucket' in local_var_params:
            query_params.append(('bucket', local_var_params['bucket']))  # noqa: E501
        if 'precision' in local_var_params:
            query_params.append(('precision', local_var_params['precision']))  # noqa: E501

        header_params = {}
        if 'zap_trace_span' in local_var_params:
            header_params['Zap-Trace-Span'] = local_var_params['zap_trace_span']  # noqa: E501
        if 'content_encoding' in local_var_params:
            header_params['Content-Encoding'] = local_var_params['content_encoding']  # noqa: E501
        if 'content_type' in local_var_params:
            header_params['Content-Type'] = local_var_params['content_type']  # noqa: E501
        if 'content_length' in local_var_params:
            header_params['Content-Length'] = local_var_params['content_length']  # noqa: E501
        if 'accept' in local_var_params:
            header_params['Accept'] = local_var_params['accept']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/write', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Influx API Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Tasks(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'links': 'Links',
        'tasks': 'list[Task]'
    }

    attribute_map = {
        'links': 'links',
        'tasks': 'tasks'
    }

    def __init__(self, links=None, tasks=None):  # noqa: E501
        """Tasks - a model defined in OpenAPI"""  # noqa: E501

        self._links = None
        self._tasks = None
        self.discriminator = None

        if links is not None:
            self.links = links
        if tasks is not None:
            self.tasks = tasks

    @property
    def links(self):
        """Gets the links of this Tasks.  # noqa: E501


        :return: The links of this Tasks.  # noqa: E501
        :rtype: Links
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Tasks.


        :param links: The links of this Tasks.  # noqa: E501
        :type: Links
        """

        self._links = links

    @property
    def tasks(self):
        """Gets the tasks of this Tasks.  # noqa: E501


        :return: The tasks of this Tasks.  # noqa: E501
        :rtype: list[Task]
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this Tasks.


        :param tasks: The tasks of this Tasks.  # noqa: E501
        :type: list[Task]
        """

        self._tasks = tasks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Tasks):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
